@@ -85,10 +85,10 @@ class SecurityEvent(BaseModel):
     severity: SeverityLevel
     description: str = Field(description="Detailed event description")
     confidence_score: float = Field(ge=0.0, le=1.0, description="Confidence level (0.0-1.0)")
-    source_ips: str = Field(description="Source IP address")
-    dest_ips: str = Field(description="Destination IP address")
-    source_port: int = Field(description="Source port number")
-    dest_port: int = Field(description="Destination port number")
+    source_ips: list[str] = Field(description="Source IP list")
+    dest_ips: list[str] = Field(description="Destination IP list")
+    source_ports: list[int] = Field(description="Source port number list")
+    dest_ports: list[int] = Field(description="Destination port number list")
     protocol: PacketProtocol
     payload_content: str = Field(description="Payload content if detected")
     attack_patterns: list[PacketSecurityEvent] = Field(description="Detected attack patterns")
@@ -109,11 +109,10 @@ class Statistics(BaseModel):
 class PacketAnalysis(BaseModel):
     summary: str = Field(description="Analysis summary")
     events: list[SecurityEvent] = Field(
-        min_items=1,
-        description="List of security events - must include at least one"
+        description="List of security events - may be empty if no security concerns detected"
     )
     statistics: Statistics
-    highest_severity: SeverityLevel
+    highest_severity: Optional[SeverityLevel] = Field(description="Highest severity level of detected events (null if no events)")
     requires_immediate_attention: bool = Field(description="Requires immediate attention")
 #--------------------------------------------------------------------------------------
 
@@ -182,10 +181,16 @@ def assign_logid_to_packets(packets):
 
 def run_batch_analysis(ssh_config=None, log_path=None):
     """Run batch analysis on static log file"""
+    from ..core.config import LLM_PROVIDER, LLM_MODELS
+    
     print("=" * 70)
     print("LogSentinelAI - TCPDump Packet Analysis (Batch Mode)")
     print("=" * 70)
     
+    # Get LLM configuration
+    llm_provider = LLM_PROVIDER
+    llm_model_name = LLM_MODELS.get(LLM_PROVIDER, "unknown")
+    
     # Get analysis configuration (can override chunk_size if needed)
     # config = get_analysis_config("tcpdump_packet", chunk_size=3)  # Override chunk_size
     config = get_analysis_config("tcpdump_packet")  # Use default chunk_size
@@ -194,12 +199,18 @@ def run_batch_analysis(ssh_config=None, log_path=None):
     if log_path:
         config['log_path'] = log_path
     
+    # Determine access mode
+    access_mode = "SSH (Remote)" if ssh_config else "LOCAL"
+    
+    print(f"Access mode:       {access_mode}")
     print(f"Log file:          {config['log_path']}")
     print(f"Chunk size:        {config['chunk_size']}")
     print(f"Response language: {config['response_language']}")
-    print(f"Analysis mode:     {config['analysis_mode']}")
+    print(f"LLM Provider:      {llm_provider}")
+    print(f"LLM Model:         {llm_model_name}")
     if ssh_config:
-        print("Access mode:       SSH (Remote)")
+        print(f"SSH Target:        {ssh_config.get('user', 'unknown')}@{ssh_config.get('host', 'unknown')}:{ssh_config.get('port', 22)}")
+    print("=" * 70)
     
     log_path = config["log_path"]
     chunk_size = config["chunk_size"]
@@ -226,6 +237,12 @@ def run_batch_analysis(ssh_config=None, log_path=None):
             logs = "".join(chunk).replace('\\n', '\n')  # Convert escaped newlines back
             model_schema = PacketAnalysis.model_json_schema()
             prompt = get_tcpdump_packet_prompt().format(logs=logs, model_schema=model_schema, response_language=response_language)
+            prompt = prompt.strip()
+            if i == 0:
+                print("\n[LLM Prompt Submitted]")
+                print("-" * 50)
+                print(prompt)
+                print("-" * 50)
             print(f"\n--- Chunk {i+1} ---")
             print_chunk_contents(chunk)
             
